@@ -7,14 +7,17 @@
  * Created Sun Jun 16 21:12:20 CEST 2002
  * 
  * Version:
- * $Id: pam_linux_uniklu_cleanup_password.c,v 1.4 2009-01-09 10:17:09 agebhard Exp $
+ * $Id: pam_linux_uniklu_cleanup_password.c,v 1.5 2009-01-11 15:38:07 agebhard Exp $
  * 
  * Last Revised on
- * $Date: 2009-01-09 10:17:09 $
+ * $Date: 2009-01-11 15:38:07 $
  * 
  * Changelog:
  *
  * $Log: pam_linux_uniklu_cleanup_password.c,v $
+ * Revision 1.5  2009-01-11 15:38:07  agebhard
+ * reduce compiler warnings
+ *
  * Revision 1.4  2009-01-09 10:17:09  agebhard
  * ...
  *
@@ -29,6 +32,7 @@
  */
 
 #include <string.h>
+#include <stdlib.h>
 #include "pam_linux_uniklu.h"
 
 extern void	pam_linux_uniklu_cleanup_password(pam_handle_t *pamh,
